LineStyle

Enum LineStyle 

pub enum LineStyle {
    Identifying,
    NonIdentifying,
}
Connector style between two cardinality halves of a relationship. Mermaid distinguishes -- (identifying — solid line, child cannot exist without parent) from .. (non-identifying — dashed line, looser association).

Variants



Identifying

-- — solid line. Child entity’s identity depends on parent’s.



NonIdentifying

.. — dashed line. Looser association.

Implementations

Source

impl LineStyle

pub fn is_dashed(self) -> bool

True for .. (dashed) — used by the renderer to pick over for the relationship line glyph.