pub struct AxisLabels {
pub low: String,
pub high: String,
}Expand description
Axis label pair for one dimension of the quadrant chart.
low is the label at the origin-side of the axis;
high is the label at the far end.
Fields
low: Stringhigh: StringTrait Implementations
Sourceimpl Clone for AxisLabels
impl Clone for AxisLabels
Sourcefn clone(&self) -> AxisLabels
fn clone(&self) -> AxisLabels
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AxisLabels
impl Debug for AxisLabels
Sourceimpl Default for AxisLabels
impl Default for AxisLabels
Sourcefn default() -> AxisLabels
fn default() -> AxisLabels
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for AxisLabels
impl PartialEq for AxisLabels
Sourcefn eq(&self, other: &AxisLabels) -> bool
fn eq(&self, other: &AxisLabels) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for AxisLabels
impl StructuralPartialEq for AxisLabels