ClickTarget

Struct ClickTarget 

pub struct ClickTarget {
    pub url: String,
    pub tooltip: Option<String>,
}
A hyperlink target attached to a node via a Mermaid click directive.

When rendered in a terminal that supports OSC 8, the node’s label text is wrapped with the appropriate escape sequences so it becomes a clickable hyperlink. In terminals that do not support OSC 8 the escape bytes are emitted but harmlessly ignored (or stripped by crate::to_ascii in ASCII mode).

Examples

use mermaid_text::types::ClickTarget;

let ct = ClickTarget { url: "https://example.com".to_string(), tooltip: None };
assert_eq!(ct.url, "https://example.com");

Fields

url: String

The URL to open when the node label is clicked.

tooltip: Option<String>

Optional tooltip text (from the third argument of click NodeId "url" "tooltip"). Not rendered in the terminal output but preserved for future use.